Learn R Programming

geneHummus (version 1.0.11)

accessions_from_spp: Extract the accession ids (XP accession) for a given organism

Description

Filter a dataframe of protein ids and return the accessions for a given species or organism.

Usage

accessions_from_spp(my_accessions, spp)

Arguments

my_accessions

A data frame with accession protein ids and organisms

spp

A string with the scientific name of the species or organism.

Value

A string vector with protein accession (XP accession, RefSeq database)

See Also

getAccessions to create the data frame with accession id and organism for each protein identifier.

Examples

Run this code
# NOT RUN {
my_prots = data.frame(accession = c("XP_014620925", "XP_003546066", 
   "XP_025640041", "XP_019453956", "XP_006584791", "XP_020212415", 
   "XP_017436622", "XP_004503803", "XP_019463844"),
   organism =  c("Glycine max", "Glycine max", "Arachis hypogaea",
   "Lupinus angustifolius", "Glycine max", "Cajanus cajan", 
   "Vigna angularis", "Cicer arietinum", "Lupinus angustifolius"))
   
accessions_from_spp(my_prots, "Glycine max")
 
# }

Run the code above in your browser using DataLab