Learn R Programming

geneHummus (version 1.0.11)

extract_proteins: Get the protein identifiers

Description

Extract the protein identifier for the given taxonomic species, which are hosted by the RefSeq database (NCBI).

Usage

extract_proteins(targets, taxonIds)

Arguments

targets

A string with the electronic links for the SPARCLE architecture.

taxonIds

A string with the taxonomic species identifiers; legume species (by default).

Details

First, get the protein ids from RefSeq database. Then, extract only the ids for the selected taxonomic species (by default, legume species).