Learn R Programming

geneHummus (version 1.0.11)

filterarchids_warning: Filter protein architectures based on conserved domains

Description

Parse the architecture identifiers and extract those that contain, at least, the conserved domaind selected as filter.

Usage

filterarchids_warning(archs_ids, filter)

Arguments

archs_ids

A string with the architecture identifiers.

filter

A string with the domains as filter.