Extract the protein identifier for the given taxonomic species, which are hosted by the RefSeq database (NCBI).
extract_proteins(targets, taxonIds)A string with the electronic links for the SPARCLE architecture.
A string with the taxonomic species identifiers; legume species (by default).
First, get the protein ids from RefSeq database. Then, extract only the ids for the selected taxonomic species (by default, legume species).